@@ -76,6 +76,10 @@ typedef enum
 #define EPHY_PREFS_WEB_FONT_MIN_SIZE		"min-font-size"
 #define EPHY_PREFS_WEB_LANGUAGE			"language"
 #define EPHY_PREFS_WEB_USE_OWN_FONTS		"use-own-fonts"
+#define EPHY_PREFS_WEB_USE_GNOME_FONTS		"use-gnome-fonts"
+#define EPHY_PREFS_WEB_SANS_SERIF_FONT		"sans-serif-font"
+#define EPHY_PREFS_WEB_SERIF_FONT		"serif-font"
+#define EPHY_PREFS_WEB_MONOSPACE_FONT		"monospace-font"
 #define EPHY_PREFS_WEB_USE_OWN_COLORS		"use-own-colors"
 #define EPHY_PREFS_WEB_ENABLE_USER_CSS		"enable-user-css"
 #define EPHY_PREFS_WEB_ENABLE_POPUPS		"enable-popups"
