@@ -30,9 +30,10 @@
 #include "ephy-location-entry.h"
 #include "ephy-location-action.h"
 #include "ephy-navigation-action.h"
+#include "ephy-navigation-history-action.h"
+#include "ephy-navigation-up-action.h"
 #include "ephy-topic-action.h"
 #include "ephy-zoom-action.h"
-#include "ephy-spinner-tool-item.h"
 #include "ephy-dnd.h"
 #include "ephy-shell.h"
 #include "ephy-stock-icons.h"
@@ -44,6 +45,13 @@
 #include <gtk/gtk.h>
 #include <string.h>
 
+/**
+ * SECTION:ephy-toolbar
+ * @short_description: Epiphany's toolbar widget
+ *
+ * #EphyToolbar is a customized #EggEditableToolbar.
+ */
+
 enum
 {
 	BACK_ACTION,
@@ -54,11 +62,6 @@ enum
 	LAST_ACTION
 };
 
-enum
-{
-	SENS_FLAG = 1 << 0
-};
-
 #define EPHY_TOOLBAR_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_TOOLBAR, EphyToolbarPrivate))
 
 struct _EphyToolbarPrivate
@@ -67,7 +70,6 @@ struct _EphyToolbarPrivate
 	GtkActionGroup *action_group;
 	GtkAction *actions[LAST_ACTION];
 	GtkWidget *fixed_toolbar;
-	EphySpinnerToolItem *spinner;
 	GtkToolItem *sep_item;
 	GtkToolItem *exit_button;
 	gulong set_focus_handler;
@@ -128,17 +130,10 @@ ephy_toolbar_update_fixed_visibility (EphyToolbar *toolbar)
 
 	show = priv->leave_fullscreen_visible;
 	g_object_set (priv->sep_item, "visible", show, NULL);
+	g_object_set (priv->exit_button, "visible", show, NULL);
 	g_object_set (priv->fixed_toolbar, "visible", show, NULL);
 }
 
-static void
-ephy_toolbar_update_spinner (EphyToolbar *toolbar)
-{
-	EphyToolbarPrivate *priv = toolbar->priv;
-
-	ephy_spinner_tool_item_set_spinning (priv->spinner, priv->spinning);
-}
-
 static void 
 maybe_finish_activation_cb (EphyWindow *window,
 			    GtkWidget *widget,
@@ -183,7 +178,7 @@ sync_user_input_cb (EphyLocationAction *action,
 	address = ephy_location_action_get_address (action);
 
 	priv->updating_address = TRUE;
-	ephy_web_view_set_typed_address (EPHY_GET_EPHY_WEB_VIEW_FROM_EMBED (embed), address);
+	ephy_web_view_set_typed_address (ephy_embed_get_web_view (embed), address);
 	priv->updating_address = FALSE;
 }
 
@@ -218,7 +213,7 @@ ephy_toolbar_set_window (EphyToolbar *toolbar,
 	g_object_unref (priv->action_group);
 
 	action = priv->actions[BACK_ACTION] =
-		g_object_new (EPHY_TYPE_NAVIGATION_ACTION,
+		g_object_new (EPHY_TYPE_NAVIGATION_HISTORY_ACTION,
 			      "name", "NavigationBack",
 			      "label", _("_Back"),
 			      "stock_id", GTK_STOCK_GO_BACK,
@@ -228,7 +223,7 @@ ephy_toolbar_set_window (EphyToolbar *toolbar,
 			       */
 			      "arrow-tooltip", _("Back history"),
 			      "window", priv->window,
-			      "direction", EPHY_NAVIGATION_DIRECTION_BACK,
+			      "direction", EPHY_NAVIGATION_HISTORY_DIRECTION_BACK,
 			      "is_important", TRUE,
 			      NULL);
 	g_signal_connect_swapped (action, "open-link",
@@ -238,7 +233,7 @@ ephy_toolbar_set_window (EphyToolbar *toolbar,
 	g_object_unref (action);
 
 	action = priv->actions[FORWARD_ACTION] =
-		g_object_new (EPHY_TYPE_NAVIGATION_ACTION,
+		g_object_new (EPHY_TYPE_NAVIGATION_HISTORY_ACTION,
 			      "name", "NavigationForward",
 			      "label", _("_Forward"),
 			      "stock_id", GTK_STOCK_GO_FORWARD,
@@ -248,7 +243,7 @@ ephy_toolbar_set_window (EphyToolbar *toolbar,
 			       */
 			      "arrow-tooltip", _("Forward history"),
 			      "window", priv->window,
-			      "direction", EPHY_NAVIGATION_DIRECTION_FORWARD,
+			      "direction", EPHY_NAVIGATION_HISTORY_DIRECTION_FORWARD,
 			      NULL);
 	g_signal_connect_swapped (action, "open-link",
 				  G_CALLBACK (ephy_link_open), toolbar);
@@ -257,7 +252,7 @@ ephy_toolbar_set_window (EphyToolbar *toolbar,
 	g_object_unref (action);
 
 	action = priv->actions[UP_ACTION] =
-		g_object_new (EPHY_TYPE_NAVIGATION_ACTION,
+		g_object_new (EPHY_TYPE_NAVIGATION_UP_ACTION,
 			      "name", "NavigationUp",
 			      "label", _("_Up"),
 			      "stock_id", GTK_STOCK_GO_UP,
@@ -267,7 +262,6 @@ ephy_toolbar_set_window (EphyToolbar *toolbar,
 			       */
 			      "arrow-tooltip", _("List of upper levels"),
 			      "window", priv->window,
-			      "direction", EPHY_NAVIGATION_DIRECTION_UP,
 			      NULL);
 	g_signal_connect_swapped (action, "open-link",
 				  G_CALLBACK (ephy_link_open), toolbar);
@@ -358,12 +352,27 @@ ephy_toolbar_set_window (EphyToolbar *toolbar,
 
 /* public functions */
 
+/**
+ * ephy_toolbar_get_action_group:
+ * @toolbar: an #EphyToolbar widget
+ *
+ * Gets the #GtkActionGroup for @toolbar.
+ *
+ * Return value: (transfer none): the #GtkActionGroup associated with @toolbar
+ **/
 GtkActionGroup *
 ephy_toolbar_get_action_group (EphyToolbar *toolbar)
 {
    return toolbar->priv->action_group;   
 }
 
+/**
+ * ephy_toolbar_set_favicon:
+ * @toolbar: an #EphyToolbar widget
+ * @icon: a #GdkPixbuf icon
+ *
+ * Sets @icon to be the favicon of @toolbar's internal #EphyLocationEntry.
+ **/
 void
 ephy_toolbar_set_favicon (EphyToolbar *toolbar,
 			  GdkPixbuf *icon)
@@ -373,6 +382,13 @@ ephy_toolbar_set_favicon (EphyToolbar *toolbar,
 	g_object_set (priv->actions[LOCATION_ACTION], "icon", icon, NULL);
 }
 
+/**
+ * ephy_toolbar_set_show_leave_fullscreen:
+ * @toolbar: an #EphyToolbar widget
+ * @show: %TRUE to show the leave fullscreen button
+ *
+ * Tells @toolbar if it should show the leave fullscreen button or not.
+ **/
 void
 ephy_toolbar_set_show_leave_fullscreen (EphyToolbar *toolbar,
 					gboolean show)
@@ -384,6 +400,12 @@ ephy_toolbar_set_show_leave_fullscreen (EphyToolbar *toolbar,
 	ephy_toolbar_update_fixed_visibility (toolbar);
 }
 
+/**
+ * ephy_toolbar_activate_location:
+ * @toolbar: an #EphyToolbar widget
+ *
+ * Calls ephy_location_entry_activate on @toolbar's internal #EphyLocationEntry.
+ **/
 void
 ephy_toolbar_activate_location (EphyToolbar *toolbar)
 {
@@ -420,6 +442,14 @@ ephy_toolbar_activate_location (EphyToolbar *toolbar)
 	ephy_location_entry_activate (EPHY_LOCATION_ENTRY (entry));
 }
 
+/**
+ * ephy_toolbar_get_location:
+ * @toolbar: an #EphyToolbar widget
+ *
+ * Gets the current address according to @toolbar's #EphyLocationAction.
+ *
+ * Returns: current @toolbar address
+ **/
 const char *
 ephy_toolbar_get_location (EphyToolbar *toolbar)
 {
@@ -429,10 +459,16 @@ ephy_toolbar_get_location (EphyToolbar *toolbar)
 	return ephy_location_action_get_address (action);
 }
 
+/**
+ * ephy_toolbar_set_location:
+ * @toolbar: an #EphyToolbar widget
+ * @address: new address
+ *
+ * Sets the internal #EphyLocationAction address to @address.
+ **/
 void
 ephy_toolbar_set_location (EphyToolbar *toolbar,
-			   const char *address,
-			   const char *typed_address)
+			   const char *address)
 {
 	EphyToolbarPrivate *priv = toolbar->priv;
 	EphyLocationAction *action = EPHY_LOCATION_ACTION (priv->actions[LOCATION_ACTION]);
@@ -440,10 +476,19 @@ ephy_toolbar_set_location (EphyToolbar *toolbar,
 	if (priv->updating_address) return;
 
 	priv->updating_address = TRUE;
-	ephy_location_action_set_address (action, address, typed_address);
+	ephy_location_action_set_address (action, address);
 	priv->updating_address = FALSE;
 }
 
+/**
+ * ephy_toolbar_set_navigation_actions:
+ * @toolbar: an #EphyToolbar widget
+ * @back: %TRUE if possible to go backward
+ * @forward: %TRUE if possible to go forward
+ * @up: %TRUE if possible to go up
+ *
+ * Sets the sensivity of navigation buttons in the @toolbar.
+ **/
 void
 ephy_toolbar_set_navigation_actions (EphyToolbar *toolbar,
 				     gboolean back,
@@ -457,6 +502,15 @@ ephy_toolbar_set_navigation_actions (EphyToolbar *toolbar,
 	ephy_action_change_sensitivity_flags (priv->actions[UP_ACTION], SENS_FLAG, !up);
 }
 
+/**
+ * ephy_toolbar_set_navigation_tooltips:
+ * @toolbar: an #EphyToolbar widget
+ * @back_title: text for back button tooltip
+ * @forward_title: text for forward button tooltip
+ *
+ * Sets the titles of back and forward pages as the tooltips of its corresponding
+ * navigation buttons.
+ **/
 void
 ephy_toolbar_set_navigation_tooltips (EphyToolbar *toolbar,
 				      const char *back_title,
@@ -477,6 +531,16 @@ ephy_toolbar_set_navigation_tooltips (EphyToolbar *toolbar,
 	g_value_unset (&value);
 }
 
+/**
+ * ephy_toolbar_set_security_state:
+ * @toolbar: an #EphyToolbar widget
+ * @is_secure: %TRUE if the page is loaded over a secure connection
+ * @show_lock: %TRUE to show the lock icon in the location entry
+ * @stock_id: stock-id to be used as the lock icon
+ * @tooltip: tooltip for the lock icon
+ *
+ * Sets properties on the lock icon inside the internal #EphyLocationEntry.
+ **/
 void
 ephy_toolbar_set_security_state (EphyToolbar *toolbar,
 				 gboolean is_secure,
@@ -497,17 +561,14 @@ ephy_toolbar_set_security_state (EphyToolbar *toolbar,
 		      NULL);
 }
 
-void
-ephy_toolbar_set_spinning (EphyToolbar *toolbar,
-			   gboolean spinning)
-{
-	EphyToolbarPrivate *priv = toolbar->priv;
-
-	priv->spinning = spinning != FALSE;
-
-	ephy_toolbar_update_spinner (toolbar);
-}
-
+/**
+ * ephy_toolbar_set_zoom:
+ * @toolbar: an #EphyToolbar widget
+ * @can_zoom: %TRUE if the current #EphyWebView can zoom
+ * @zoom: new zoom level
+ *
+ * Sets the zoom level to @zoom, but only if @can_zoom is %TRUE.
+ **/
 void
 ephy_toolbar_set_zoom (EphyToolbar *toolbar,
 		       gboolean can_zoom,
@@ -521,26 +582,6 @@ ephy_toolbar_set_zoom (EphyToolbar *toolbar,
 
 /* Class implementation */
 
-static void
-ephy_toolbar_show (GtkWidget *widget)
-{
-	EphyToolbar *toolbar = EPHY_TOOLBAR (widget);
-
-	GTK_WIDGET_CLASS (ephy_toolbar_parent_class)->show (widget);
-
-	ephy_toolbar_update_spinner (toolbar);
-}
-
-static void
-ephy_toolbar_hide (GtkWidget *widget)
-{
-	EphyToolbar *toolbar = EPHY_TOOLBAR (widget);
-
-	GTK_WIDGET_CLASS (ephy_toolbar_parent_class)->hide (widget);
-
-	ephy_toolbar_update_spinner (toolbar);
-}
-
 static void
 ephy_toolbar_init (EphyToolbar *toolbar)
 {
@@ -570,10 +611,6 @@ ephy_toolbar_constructor (GType type,
 	gtoolbar = GTK_TOOLBAR (priv->fixed_toolbar);
 	gtk_toolbar_set_show_arrow (gtoolbar, FALSE);
 
-	priv->spinner = EPHY_SPINNER_TOOL_ITEM (ephy_spinner_tool_item_new ());
-	gtk_toolbar_insert (gtoolbar, GTK_TOOL_ITEM (priv->spinner), -1);
-	gtk_widget_show (GTK_WIDGET (priv->spinner));
-
 	priv->sep_item = gtk_separator_tool_item_new ();
 	gtk_toolbar_insert (gtoolbar, priv->sep_item, -1);
 
@@ -636,16 +673,19 @@ static void
 ephy_toolbar_class_init (EphyToolbarClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
-	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
 	object_class->constructor = ephy_toolbar_constructor;
 	object_class->finalize = ephy_toolbar_finalize;
 	object_class->set_property = ephy_toolbar_set_property;
 	object_class->get_property = ephy_toolbar_get_property;
 
-	widget_class->show = ephy_toolbar_show;
-	widget_class->hide = ephy_toolbar_hide;
-
+	/**
+	* EphyToolbar::activation-finished:
+	* @toolbar: the object which received the signal.
+	*
+	* Emitted when the user clicks on the security icon of the internal
+	* #EphyLocationEntry.
+	*/
 	signals[ACTIVATION_FINISHED] =
 		g_signal_new ("activation-finished",
 			      G_OBJECT_CLASS_TYPE (object_class),
@@ -656,6 +696,13 @@ ephy_toolbar_class_init (EphyToolbarClass *klass)
 			      G_TYPE_NONE,
 			      0);
 
+	/**
+	* EphyToolbar::exit-clicked:
+	* @toolbar: the object which received the signal.
+	*
+	* Emitted when the user clicks on the security icon of the internal
+	* #EphyLocationEntry.
+	*/
 	signals[EXIT_CLICKED] =
 		g_signal_new
 			("exit-clicked",
@@ -667,6 +714,13 @@ ephy_toolbar_class_init (EphyToolbarClass *klass)
 			 G_TYPE_NONE,
 			 0);
 
+	/**
+	* EphyToolbar::lock-clicked:
+	* @toolbar: the object which received the signal.
+	*
+	* Emitted when the user clicks on the security icon of the internal
+	* #EphyLocationEntry.
+	*/
 	signals[LOCK_CLICKED] =
 		g_signal_new
 			("lock-clicked",
@@ -677,7 +731,12 @@ ephy_toolbar_class_init (EphyToolbarClass *klass)
 			 g_cclosure_marshal_VOID__VOID,
 			 G_TYPE_NONE,
 			 0);
-
+	/**
+	* EphyToolbar:window:
+	* @toolbar: the object which received the signal.
+	*
+	* Parent window of the toolbar.
+	*/
 	g_object_class_install_property (object_class,
 					 PROP_WINDOW,
 					 g_param_spec_object ("window",
@@ -690,6 +749,14 @@ ephy_toolbar_class_init (EphyToolbarClass *klass)
 	g_type_class_add_private (object_class, sizeof(EphyToolbarPrivate));
 }
 
+/**
+ * ephy_toolbar_new:
+ * @window: parent window for the toolbar
+ *
+ * Creates a new #EphyToolbar and associates it with @window.
+ *
+ * Returns: a new #EphyToolbar
+ **/
 EphyToolbar *
 ephy_toolbar_new (EphyWindow *window)
 {
